@@ -24,13 +24,13 @@ def color(S):
 
 def algo(A,B,G):
     C1, T1 = calc(A,B,G)
+
     if T1 - int(T1) == 0:
         C2, T2 = calc(B,A,G)
         if T2 - int(T2) != 0:
             C2 , T2 = [], 1000000000.
     else:
         C2 , T2 = [], 1000000000.
-
     if T1 < T2:
         return C1, T1
     else:
@@ -40,7 +40,7 @@ def algo(A,B,G):
 def calc(Deb, Fin,G):                
                 """
                 visit http://en.wikipedia.org/wiki/Dijkstra%27s_algorithm for more information """
-                print 'Dijkstra : %s --> %s'%(Deb,Fin)
+                #print 'Dijkstra : %s --> %s'%(Deb,Fin)
                 reload(station)
                 noeuds = station.station
                 graph = G
@@ -70,9 +70,9 @@ def calc(Deb, Fin,G):
                                 
                                 l__old_vertex = noeuds[l__current_vertex][3]
                                 
-                                if l__successors.count(l__old_vertex) > 0:
+                                if l__old_vertex in  l__successors:
                                     l__old_edge = l__successors.index(l__old_vertex)
-                                elif l__successors.count(l__old_vertex) == 0:
+                                else:
                                     if len(l__successors) % 2 == 1 and not station.LigneM in l__successorsColor and l__current_vertex != 'Saint-Lazare':
                                         l__old_edge = -2
                                         #print '=== il y a un sens unique'
@@ -89,17 +89,17 @@ def calc(Deb, Fin,G):
                                                 
 
                                                 #if l__successorsColor[l__current_edge] != QtGui.QColor(103,47,143):
-                                                l__newTentativeDistance = int(noeuds[l__current_vertex][0] + math.sqrt( (graph[l__current_vertex].x() - graph[l__successor].x())**2 + (graph[l__current_vertex].y() - graph[l__successor].y())**2)) + 60.
+                                                l__newTentativeDistance = noeuds[l__current_vertex][0] + int(math.sqrt( (graph[l__current_vertex].x() - graph[l__successor].x())**2 + (graph[l__current_vertex].y() - graph[l__successor].y())**2)) + 60.
                                                 #else:
                                                 #   l__newTentativeDistance = noeuds[l__current_vertex][0] + math.sqrt( (X(l__current_vertex) - X(l__successor))**2 + (Y(l__current_vertex) - Y(l__successor))**2)*.75
+
+                                                if l__old_edge == -2:
+                                                        
+                                                    l__newTentativeDistance +=  00.01
                                                 
                                                 if graph[l__current_vertex].colorIni.color() == station.LigneM and l__old_edge != -1:
-
-                                                        if l__old_edge == -2:
-                                                        
-                                                            l__newTentativeDistance +=  00.01
                                                             
-                                                        elif l__successorsColor[l__current_edge] != l__successorsColor[l__old_edge]:
+                                                        if l__successorsColor[l__current_edge] != l__successorsColor[l__old_edge]:
                                                             #print '         Pas meme couleur entre les points' , [l__old_vertex, l__current_vertex, l__successor]
                                                             l__newTentativeDistance += 200.
                                                             if l__successorsColor[l__old_edge] in [station.Ligne14,station.RERA,station.RERB,station.RERC,station.RERD,station.RERE] :
