@@ -136,6 +136,11 @@ class Ui_MainWindow(QMainWindow):
             #Start anim
             self.view.animSeq.addAnimation(animParIn)
             self.view.animSeq.addPause(_TEMPS_ANIM/2)
+            
+            minH = graph[self.Chemin[0]].x()
+            maxH = graph[self.Chemin[0]].x()
+            minV = graph[self.Chemin[0]].y()
+            maxV = graph[self.Chemin[0]].y()
 
             #Follow stations
             while i < n+1:
@@ -145,6 +150,10 @@ class Ui_MainWindow(QMainWindow):
                 anim.setKeyValueAt(0, graph[self.Chemin[i-1]].pos()  )
                 anim.setKeyValueAt(1, graph[self.Chemin[i]].pos()  )
                 self.view.animSeq.addAnimation(anim)
+                minH = min(minH,graph[self.Chemin[i]].x())
+                maxH = max(maxH,graph[self.Chemin[i]].x())
+                minV = min(minV,graph[self.Chemin[i]].y())
+                maxV = max(maxV,graph[self.Chemin[i]].y())
                 i += 1
     
 
@@ -155,11 +164,11 @@ class Ui_MainWindow(QMainWindow):
             animUnCenter.setEasingCurve(QEasingCurve.OutQuad)
             animUnCenter.setKeyValueAt(0, graph[self.Chemin[-1]].pos())
             
-            dx = abs(graph[self.Chemin[-1]].x() - graph[self.Chemin[0]].x())
-            dy = abs(graph[self.Chemin[-1]].y() - graph[self.Chemin[0]].y())
+            dx = abs(maxH - minH)
+            dy = abs(maxV - minV)
             
-            x = (graph[self.Chemin[-1]].x() + graph[self.Chemin[0]].x())/2
-            y = (graph[self.Chemin[-1]].y() + graph[self.Chemin[0]].y())/2
+            x = (maxH + minH)/2
+            y = (maxV + minV)/2
             animUnCenter.setKeyValueAt(1, QPointF(  x,  y ))
 
             #Anime UnZoom    
@@ -169,9 +178,10 @@ class Ui_MainWindow(QMainWindow):
             Sx = (w/(dx+10))
             Sy = (h/(dy+10))
             S = max(min(Sx,Sy,5.0),.21)
-#            print w, h, dx
 
-            val = ((S) /5.)**(.2)
+
+            val = ((S) /5.)**(.15)
+
             
             animUnZoom = QPropertyAnimation (self.view, "scaling")
             animUnZoom.setDuration(_TEMPS_ANIM*2)
@@ -449,6 +459,7 @@ class Ui_MainWindow(QMainWindow):
     def colorise(self):
         self.scene.blur()
         self.CheminItem = []
+
         if self.Selec[0] == 'GPS':
             proche = self.gpsSearch(self.gps.pos())
             graph['GPS'].addCorres(str(proche))
@@ -496,6 +507,12 @@ class Ui_MainWindow(QMainWindow):
             self.CheminItem.append(ellipse)
             dep = dest
         dep = self.Chemin[0]
+
+        minH = graph[self.Chemin[0]].x()
+        maxH = graph[self.Chemin[0]].x()
+        minV = graph[self.Chemin[0]].y()
+        maxV = graph[self.Chemin[0]].y()
+
         for dest in self.Chemin:
             if not dest[:-4] in graph[dep].name or dest == dep:
                 if dest[-1] == ']':
@@ -524,6 +541,12 @@ class Ui_MainWindow(QMainWindow):
     
                 self.CheminItem.append(txtOmbre)
                 self.CheminItem.append(txt)
+
+                minH = min(minH,graph[dest].x())
+                maxH = max(maxH,graph[dest].x())
+                minV = min(minV,graph[dest].y())
+                maxV = max(maxV,graph[dest].y())
+
             dep = dest
 
         for item in self.CheminItem:
@@ -537,6 +560,46 @@ class Ui_MainWindow(QMainWindow):
         self.animTemps.setKeyValueAt(0, QPoint(10, -50) )
         self.animTemps.setKeyValueAt(1, QPoint(10, 0) )
         self.animTemps.start()
+    
+
+            #Anim UnCenter 
+
+        animUnCenter = QPropertyAnimation (self.view, "center")
+        animUnCenter.setDuration(_TEMPS_ANIM)
+        animUnCenter.setEasingCurve(QEasingCurve.OutQuad)
+        animUnCenter.setKeyValueAt(0, self.view.getCenter())
+            
+        dx = abs(maxH - minH)
+        dy = abs(maxV - minV)
+            
+        x = (maxH + minH)/2
+        y = (maxV + minV)/2
+        animUnCenter.setKeyValueAt(1, QPointF(  x,  y ))
+
+            #Anime UnZoom    
+            
+        w = self.width()
+        h = self.height()
+        Sx = (w/(dx+10))
+        Sy = (h/(dy+10))
+        S = max(min(Sx,Sy,5.0),.21)
+
+        val = ((S) /self.view.getScale())**(.17)
+            
+        animUnZoom = QPropertyAnimation (self.view, "scaling")
+        animUnZoom.setDuration(_TEMPS_ANIM)
+        animUnZoom.setEasingCurve(QEasingCurve.Linear)
+        animUnZoom.setKeyValueAt(0, val)
+        animUnZoom.setKeyValueAt(1, val)
+
+        animParOut = QParallelAnimationGroup()
+        animParOut.addAnimation(animUnCenter)
+        animParOut.addAnimation(animUnZoom)
+        
+        self.view.animSeq.stop()
+        self.view.animSeq.clear()
+        self.view.animSeq.addAnimation(animParOut)
+        self.view.animSeq.start()
 
         try:
             graph[str(proche)].removeCorres("GPS")
